@@ -13,8 +13,8 @@
 package Directory::Queue;
 use strict;
 use warnings;
-our $VERSION  = "1.8";
-our $REVISION = sprintf("%d.%02d", q$Revision: 1.49 $ =~ /(\d+)\.(\d+)/);
+our $VERSION  = "1.9";
+our $REVISION = sprintf("%d.%02d", q$Revision: 1.50 $ =~ /(\d+)\.(\d+)/);
 
 #
 # used modules
@@ -273,12 +273,41 @@ sub _file_write ($$$$) {
     close($fh) or dief("cannot close(%s): %s", $path, $!);
 }
 
+#
+# "touch" a file or directory
+#
+
+sub _touch ($) {
+    my($path) = @_;
+    my($time);
+
+    $time = time();
+    utime($time, $time, $path)
+        or dief("cannot utime(%d, %d, %s): %s", $time, $time, $path, $!);
+}
+
 #+++############################################################################
 #                                                                              #
 # Base Class                                                                   #
 #                                                                              #
 #---############################################################################
 
+#
+# helper to compute an "id" from the given path
+#
+
+sub _path2id ($) {
+    my($path) = @_;
+    my(@stat);
+
+    # on some operating systems, we cannot rely on inode numbers :-(
+    return($path) if $^O =~ /^(cygwin|dos|MSWin32)$/;
+    # on others, we can: device number plus inode number should be unique
+    @stat = stat($path);
+    dief("cannot stat(%s): %s", $path, $!) unless @stat;
+    return($stat[ST_DEV] . ":" . $stat[ST_INO]);
+}
+
 #
 # object creator (wrapper)
 #
@@ -300,7 +329,7 @@ sub new : method {
 
 sub _new : method {
     my($class, %option) = @_;
-    my($self, $path, @stat);
+    my($self, $path);
 
     # path is mandatory
     dief("missing option: path") unless defined($option{"path"});
@@ -312,10 +341,28 @@ sub _new : method {
         "dirs" => [],              # cached list of intermediate directories
         "elts" => [],              # cached list of elements
     };
+    # check the integer options
+    foreach my $name (qw(maxlock maxtemp rndhex umask)) {
+        next unless defined($option{$name});
+        dief("invalid %s: %s", $name, $option{$name})
+            unless $option{$name} =~ /^\d+$/;
+    }
+    # handle the maxlock option
+    if (defined($option{"maxlock"})) {
+        $self->{"maxlock"} = $option{"maxlock"};
+    } else {
+        $self->{"maxlock"} = 600;
+    }
+    # handle the maxtemp option
+    if (defined($option{"maxtemp"})) {
+        $self->{"maxtemp"} = $option{"maxtemp"};
+    } else {
+        $self->{"maxtemp"} = 300;
+    }
     # handle the rndhex option
     if (defined($option{"rndhex"})) {
         dief("invalid rndhex: %s", $option{"rndhex"})
-            unless $option{"rndhex"} =~ /^\d+$/ and $option{"rndhex"} < 16;
+            unless $option{"rndhex"} < 16;
         $self->{"rndhex"} = $option{"rndhex"};
     } else {
         $self->{"rndhex"} = int(rand(16));
@@ -323,7 +370,7 @@ sub _new : method {
     # handle the umask option
     if (defined($option{"umask"})) {
         dief("invalid umask: %s", $option{"umask"})
-            unless $option{"umask"} =~ /^\d+$/ and $option{"umask"} < 512;
+            unless $option{"umask"} < 512;
         $self->{"umask"} = $option{"umask"};
     }
     # create the toplevel directory if needed
@@ -332,16 +379,8 @@ sub _new : method {
         $path .= $name . "/";
         _special_mkdir($path, $self->{"umask"}) unless -d $path;
     }
-    # store the queue unique identifier
-    if ($^O =~ /^(cygwin|dos|MSWin32)$/) {
-        # we cannot rely on inode number :-(
-        $self->{"id"} = $self->{"path"};
-    } else {
-        # device number plus inode number should be unique
-        @stat = stat($self->{"path"});
-        dief("cannot stat(%s): %s", $self->{"path"}, $!) unless @stat;
-        $self->{"id"} = $stat[ST_DEV] . ":" . $stat[ST_INO];
-    }
+    # store the unique queue identifier
+    $self->{"id"} = _path2id($self->{"path"});
     # that's it!
     bless($self, $class);
     return($self);
@@ -424,20 +463,6 @@ sub first : method {
     return($self->next());
 }
 
-#
-# touch an element to indicate that it is still being used
-#
-
-sub touch : method {
-    my($self, $element) = @_;
-    my($time, $path);
-
-    $time = time();
-    $path = $self->{"path"} . "/" . $element;
-    utime($time, $time, $path)
-        or dief("cannot utime(%d, %d, %s): %s", $time, $time, $path, $!);
-}
-
 #
 # export control
 #
@@ -449,7 +474,7 @@ sub import : method {
     foreach my $name (
         qw(SYSBUFSIZE _name $_DirectoryRegexp $_ElementRegexp
            _file_create _file_read_bin _file_read_utf8 _file_write
-           _special_getdir _special_mkdir _special_rmdir)) {
+           _special_getdir _special_mkdir _special_rmdir _touch)) {
         $exported{$name}++;
     }
     export_control(scalar(caller()), $pkg, \%exported, @_);
@@ -497,26 +522,25 @@ filesystem for storage, security and to prevent race conditions via atomic
 operations. It focuses on simplicity, robustness and scalability.
 
 This module allows multiple concurrent readers and writers to interact with
-the same queue. A Python implementation of the same algorithm is available
-at L<https://github.com/cern-mig/python-dirq> and a Java implementation at
-L<https://github.com/cern-mig/java-dirq> so readers and writers can be
-written in different programming languages.
+the same queue. A Python implementation of the same algorithm is available at
+L<https://github.com/cern-mig/python-dirq> and a Java implementation at
+L<https://github.com/cern-mig/java-dirq> so readers and writers can be written
+in different programming languages.
 
-There is no knowledge of priority within a queue. If multiple priorities
-are needed, multiple queues should be used.
+There is no knowledge of priority within a queue. If multiple priorities are
+needed, multiple queues should be used.
 
 =head1 TERMINOLOGY
 
 An element is something that contains one or more pieces of data. With
 L<Directory::Queue::Simple> queues, an element can only contain one binary
-string. With L<Directory::Queue::Normal> queues, more complex data schemas
-can be used.
+string. With L<Directory::Queue::Normal> queues, more complex data schemas can
+be used.
 
-A queue is a "best effort" FIFO (First In - First Out) collection of
-elements.
+A queue is a "best effort" FIFO (First In - First Out) collection of elements.
 
-It is very hard to guarantee pure FIFO behavior with multiple writers
-using the same queue. Consider for instance:
+It is very hard to guarantee pure FIFO behavior with multiple writers using
+the same queue. Consider for instance:
 
 =over
 
@@ -541,15 +565,15 @@ Writer1: the add() method returns
 Who should be first in the queue, Writer1 or Writer2?
 
 For simplicity, this implementation provides only "best effort" FIFO,
-i.e. there is a very high probability that elements are processed in
-FIFO order but this is not guaranteed. This is achieved by using a
-high-resolution timer and having elements sorted by the time their
-final directory gets created.
+i.e. there is a very high probability that elements are processed in FIFO
+order but this is not guaranteed. This is achieved by using a high-resolution
+timer and having elements sorted by the time their final directory gets
+created.
 
 =head1 QUEUE TYPES
 
-Different queue types are supported. More detailed information can be found
-in the modules implementing these types:
+Different queue types are supported. More detailed information can be found in
+the modules implementing these types:
 
 =over
 
@@ -601,44 +625,42 @@ is not compatible (at filesystem level) with Directory::Queue::Normal
 
 =back
 
-L<Directory::Queue::Null> is special: it is a kind of black hole with
-the same API as the other directory queues.
+L<Directory::Queue::Null> is special: it is a kind of black hole with the same
+API as the other directory queues.
 
 =head1 LOCKING
 
 Adding an element is not a problem because the add() method is atomic.
 
-In order to support multiple reader processes interacting with the
-same queue, advisory locking is used. Processes should first lock an
-element before working with it. In fact, the get() and remove()
-methods report a fatal error if they are called on unlocked elements.
+In order to support multiple reader processes interacting with the same queue,
+advisory locking is used. Processes should first lock an element before
+working with it. In fact, the get() and remove() methods report a fatal error
+if they are called on unlocked elements.
 
-If the process that created the lock dies without unlocking the
-element, we end up with a staled lock. The purge() method can be used
-to remove these staled locks.
+If the process that created the lock dies without unlocking the element, we
+end up with a staled lock. The purge() method can be used to remove these
+staled locks.
 
-An element can basically be in only one of two states: locked or
-unlocked.
+An element can basically be in only one of two states: locked or unlocked.
 
-A newly created element is unlocked as a writer usually does not need
-to do anything more with it.
+A newly created element is unlocked as a writer usually does not need to do
+anything more with it.
 
 Iterators return all the elements, regardless of their states.
 
-There is no method to get an element state as this information is
-usually useless since it may change at any time. Instead, programs
-should directly try to lock elements to make sure they are indeed
-locked.
+There is no method to get an element state as this information is usually
+useless since it may change at any time. Instead, programs should directly try
+to lock elements to make sure they are indeed locked.
 
 =head1 CONSTRUCTOR
 
 The new() method of this module can be used to create a Directory::Queue
 object that will later be used to interact with the queue. It can have a
-C<type> attribute specifying the queue type to use. If not specified, the
-type defaults to C<Simple>.
+C<type> attribute specifying the queue type to use. If not specified, the type
+defaults to C<Simple>.
 
-This method is however only a wrapper around the constructor of the
-underlying module implementing the functionality. So:
+This method is however only a wrapper around the constructor of the underlying
+module implementing the functionality. So:
 
   $dirq = Directory::Queue->new(type => Foo, ... options ...);
 
@@ -648,9 +670,9 @@ is identical to:
 
 =head1 INHERITANCE
 
-Regardless of how the directory queue object is created, it inherits from
-the C<Directory::Queue> class. You can therefore test if an object is a
-directory queue (of any kind) by using:
+Regardless of how the directory queue object is created, it inherits from the
+C<Directory::Queue> class. You can therefore test if an object is a directory
+queue (of any kind) by using:
 
   if ($object->isa("Directory::Queue")) ...
 
@@ -687,11 +709,6 @@ return an empty string if the queue is empty
 return the next element in the queue, incrementing the iterator;
 return an empty string if there is no next element
 
-=item touch(ELEMENT)
-
-update the element's access and modification times to indicate that it
-is still being used
-
 =back
 
 =head1 SECURITY
@@ -699,17 +716,17 @@ is still being used
 There are no specific security mechanisms in this module.
 
 The elements are stored as plain files and directories. The filesystem
-security features (owner, group, permissions, ACLs...) should be used
-to adequately protect the data.
+security features (owner, group, permissions, ACLs...) should be used to
+adequately protect the data.
 
 By default, the process' umask is respected. See the class constructor
 documentation if you want an other behavior.
 
-If multiple readers and writers with different uids are expected, the
-easiest solution is to have all the files and directories inside the
-toplevel directory world-writable (i.e. umask=0). Then, the
-permissions of the toplevel directory itself (e.g. group-writable) are
-enough to control who can access the queue.
+If multiple readers and writers with different uids are expected, the easiest
+solution is to have all the files and directories inside the toplevel
+directory world-writable (i.e. umask=0). Then, the permissions of the toplevel
+directory itself (e.g. group-writable) are enough to control who can access
+the queue.
 
 =head1 SEE ALSO
 
@@ -722,4 +739,4 @@ L<Directory::Queue::Simple>.
 
 Lionel Cons L<http://cern.ch/lionel.cons>
 
-Copyright (C) CERN 2010-2013
+Copyright (C) CERN 2010-2015
