@@ -13,14 +13,14 @@
 package Directory::Queue::Normal;
 use strict;
 use warnings;
-our $VERSION  = "1.8";
-our $REVISION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+our $VERSION  = "1.9";
+our $REVISION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 
 #
 # used modules
 #
 
-use Directory::Queue qw(_name /Regexp/ /file/ /special/);
+use Directory::Queue qw(_name _touch /Regexp/ /file/ /special/);
 use No::Worries::Die qw(dief);
 use No::Worries::Stat qw(ST_MTIME ST_NLINK);
 use No::Worries::Warn qw(warnf);
@@ -205,7 +205,7 @@ sub new : method {
 
     # default object
     $self = __PACKAGE__->SUPER::_new(%option);
-    foreach my $name (qw(path umask)) {
+    foreach my $name (qw(path maxlock maxtemp rndhex umask)) {
         delete($option{$name});
     }
     # default options
@@ -384,6 +384,16 @@ sub unlock : method {
     return(1);
 }
 
+#
+# touch an element to indicate that it is still being used
+#
+
+sub touch : method {
+    my($self, $element) = @_;
+
+    _touch($self->{"path"} . "/" . $element);
+}
+
 #
 # remove a locked element from the queue
 #
@@ -651,8 +661,8 @@ sub purge : method {
     my(@list, $path, $subdirs, $oldtime, $locked);
 
     # check options
-    $option{maxtemp} = 300 unless defined($option{maxtemp});
-    $option{maxlock} = 600 unless defined($option{maxlock});
+    $option{maxtemp} = $self->{maxtemp} unless defined($option{maxtemp});
+    $option{maxlock} = $self->{maxtemp} unless defined($option{maxlock});
     foreach my $name (keys(%option)) {
         dief("unexpected option: %s", $name)
             unless $name =~ /^(maxtemp|maxlock)$/;
@@ -758,22 +768,21 @@ Directory::Queue::Normal - object oriented interface to a normal directory based
 
 =head1 DESCRIPTION
 
-The goal of this module is to offer a "normal" (as opposed to
-"simple") queue system using the underlying filesystem for storage,
-security and to prevent race conditions via atomic operations.
+The goal of this module is to offer a "normal" (as opposed to "simple") queue
+system using the underlying filesystem for storage, security and to prevent
+race conditions via atomic operations.
 
-It allows arbitrary data to be stored (see the L</SCHEMA> section for
-more information) but it has a significant disk space and speed
-overhead.
+It allows arbitrary data to be stored (see the L</SCHEMA> section for more
+information) but it has a significant disk space and speed overhead.
 
-Please refer to L<Directory::Queue> for general information about
-directory queues.
+Please refer to L<Directory::Queue> for general information about directory
+queues.
 
 =head1 CONSTRUCTOR
 
-The new() method can be used to create a Directory::Queue::Normal
-object that will later be used to interact with the queue. The
-following attributes are supported:
+The new() method can be used to create a Directory::Queue::Normal object that
+will later be used to interact with the queue. The following attributes are
+supported:
 
 =over
 
@@ -783,20 +792,29 @@ the queue toplevel directory (mandatory)
 
 =item rndhex
 
-the "random" hexadecimal digit to use in element names (aka I<R>) as a
-number between 0 and 15
-(default: randomly generated)
+the "random" hexadecimal digit to use in element names (aka I<R>) as a number
+between 0 and 15 (default: randomly generated)
 
 =item umask
 
-the umask to use when creating files and directories
-(default: use the running process' umask)
+the umask to use when creating files and directories (default: use the running
+process' umask)
 
 =item maxelts
 
 the maximum number of elements that an intermediate directory can hold
 (default: 16,000)
 
+=item maxlock
+
+default maximum time for a locked element (in seconds, default 600)
+as used by the purge() method
+
+=item maxtemp
+
+default maximum time for a temporary element (in seconds, default 300)
+as used by the purge() method
+
 =item schema
 
 the schema defining how to interpret user supplied data
@@ -806,14 +824,14 @@ the schema defining how to interpret user supplied data
 
 =head1 SCHEMA
 
-The schema defines how user supplied data is stored in the queue. It
-is only required by the add() and get() methods.
+The schema defines how user supplied data is stored in the queue. It is only
+required by the add() and get() methods.
 
 The schema must be a reference to a hash containing key/value pairs.
 
-The key must contain only alphanumerical characters. It identifies the
-piece of data and will be used as file name when storing the data
-inside the element directory.
+The key must contain only alphanumerical characters. It identifies the piece
+of data and will be used as file name when storing the data inside the element
+directory.
 
 The value represents the type of the given piece of data. It can be:
 
@@ -821,29 +839,28 @@ The value represents the type of the given piece of data. It can be:
 
 =item binary
 
-the data is a binary string (i.e. a sequence of bytes), it will be
-stored directly in a plain file with no further encoding
+the data is a binary string (i.e. a sequence of bytes), it will be stored
+directly in a plain file with no further encoding
 
 =item string
 
-the data is a text string (i.e. a sequence of characters), it will be
-UTF-8 encoded before being stored in a file
+the data is a text string (i.e. a sequence of characters), it will be UTF-8
+encoded before being stored in a file
 
 =item table
 
-the data is a reference to a hash of text strings, it will be
-serialized and UTF-8 encoded before being stored in a file
+the data is a reference to a hash of text strings, it will be serialized and
+UTF-8 encoded before being stored in a file
 
 =back
 
-By default, all pieces of data are mandatory. If you append a question
-mark to the type, this piece of data will be marked as optional. See
-the comments in the L</SYNOPSIS> section for an example.
+By default, all pieces of data are mandatory. If you append a question mark to
+the type, this piece of data will be marked as optional. See the comments in
+the L</SYNOPSIS> section for an example.
 
-By default, string or binary data is used directly. If you append an
-asterisk to the type, the data that you add or get will be by
-reference. This can be useful to avoid string copies of large amounts
-of data.
+By default, string or binary data is used directly. If you append an asterisk
+to the type, the data that you add or get will be by reference. This can be
+useful to avoid string copies of large amounts of data.
 
 =head1 METHODS
 
@@ -857,8 +874,8 @@ return a new Directory::Queue::Normal object (class method)
 
 =item copy()
 
-return a copy of the object; this can be useful to have independent
-iterators on the same queue
+return a copy of the object; this can be useful to have independent iterators
+on the same queue
 
 =item path()
 
@@ -884,27 +901,27 @@ return an empty string if there is no next element
 
 =item add(DATA)
 
-add the given data (a hash or hash reference) to the queue and return
-the corresponding element name; the schema must be known and the data
-must conform to it
+add the given data (a hash or hash reference) to the queue and return the
+corresponding element name; the schema must be known and the data must conform
+to it
 
 =item lock(ELEMENT[, PERMISSIVE])
 
 attempt to lock the given element and return true on success; if the
-PERMISSIVE option is true (which is the default), it is not a fatal
-error if the element cannot be locked and false is returned
+PERMISSIVE option is true (which is the default), it is not a fatal error if
+the element cannot be locked and false is returned
 
 =item unlock(ELEMENT[, PERMISSIVE])
 
 attempt to unlock the given element and return true on success; if the
-PERMISSIVE option is true (which is I<not> the default), it is not a
-fatal error if the element cannot be unlocked and false is returned
+PERMISSIVE option is true (which is I<not> the default), it is not a fatal
+error if the element cannot be unlocked and false is returned
 
 =item touch(ELEMENT)
 
 update the access and modification times on the element's directory to
-indicate that it is still being used; this is useful for elements that
-are locked for long periods of time (see the purge() method)
+indicate that it is still being used; this is useful for elements that are
+locked for long periods of time (see the purge() method)
 
 =item remove(ELEMENT)
 
@@ -913,28 +930,26 @@ remove the given element (which must be locked) from the queue
 =item get(ELEMENT)
 
 get the data from the given element (which must be locked) and return
-basically the same hash as what add() got (in list context, the hash
-is returned directly while in scalar context, the hash reference is
-returned instead); the schema must be knownand the data must conform
-to it
+basically the same hash as what add() got (in list context, the hash is
+returned directly while in scalar context, the hash reference is returned
+instead); the schema must be knownand the data must conform to it
 
 =item purge([OPTIONS])
 
-purge the queue by removing unused intermediate directories, removing
-too old temporary elements and unlocking too old locked elements (aka
-staled locks); note: this can take a long time on queues with many
-elements; OPTIONS can be:
+purge the queue by removing unused intermediate directories, removing too old
+temporary elements and unlocking too old locked elements (aka staled locks);
+note: this can take a long time on queues with many elements; OPTIONS can be:
 
 =over
 
 =item maxtemp
 
-maximum time for a temporary element (in seconds, default 300);
+maximum time for a temporary element (in seconds);
 if set to 0, temporary elements will not be removed
 
 =item maxlock
 
-maximum time for a locked element (in seconds, default 600);
+maximum time for a locked element (in seconds);
 if set to 0, locked elements will not be unlocked
 
 =back
@@ -943,9 +958,9 @@ if set to 0, locked elements will not be unlocked
 
 =head1 DIRECTORY STRUCTURE
 
-All the directories holding the elements and all the files holding the
-data pieces are located under the queue toplevel directory. This
-directory can contain:
+All the directories holding the elements and all the files holding the data
+pieces are located under the queue toplevel directory. This directory can
+contain:
 
 =over
 
@@ -959,13 +974,13 @@ the directory holding obsolete elements, i.e. the elements being removed
 
 =item I<NNNNNNNN>
 
-an intermediate directory holding elements; I<NNNNNNNN> is an 8-digits
-long hexadecimal number
+an intermediate directory holding elements; I<NNNNNNNN> is an 8-digits long
+hexadecimal number
 
 =back
 
-In any of the above directories, an element is stored as a single
-directory with a 14-digits long hexadecimal name I<SSSSSSSSMMMMMR> where:
+In any of the above directories, an element is stored as a single directory
+with a 14-digits long hexadecimal name I<SSSSSSSSMMMMMR> where:
 
 =over
 
@@ -983,9 +998,9 @@ is a random hexadecimal digit used to reduce name collisions
 
 =back
 
-Finally, inside an element directory, the different pieces of data are
-stored into different files, named according to the schema. A locked
-element contains in addition a directory named C<locked>.
+Finally, inside an element directory, the different pieces of data are stored
+into different files, named according to the schema. A locked element contains
+in addition a directory named C<locked>.
 
 =head1 SEE ALSO
 
@@ -995,4 +1010,4 @@ L<Directory::Queue>.
 
 Lionel Cons L<http://cern.ch/lionel.cons>
 
-Copyright (C) CERN 2010-2013
+Copyright (C) CERN 2010-2015
