@@ -13,8 +13,8 @@
 package Directory::Queue::Null;
 use strict;
 use warnings;
-our $VERSION  = "1.8";
-our $REVISION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+our $VERSION  = "1.9";
+our $REVISION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 #
 # used modules
@@ -126,23 +126,21 @@ Directory::Queue::Null - object oriented interface to a null directory based que
 
 =head1 DESCRIPTION
 
-The goal of this module is to offer a "null" queue system using the
-same API as the other directory queue implementations. The queue will
-behave like a black hole: added data will disappear immediately so the
-queue will therefore always appear empty.
+The goal of this module is to offer a "null" queue system using the same API
+as the other directory queue implementations. The queue will behave like a
+black hole: added data will disappear immediately so the queue will therefore
+always appear empty.
 
-This can be used for testing purposes or to discard data like one
-would do on Unix by redirecting output to C</dev/null>.
+This can be used for testing purposes or to discard data like one would do on
+Unix by redirecting output to C</dev/null>.
 
-Please refer to L<Directory::Queue> for general information about
-directory queues.
+Please refer to L<Directory::Queue> for general information about directory
+queues.
 
 =head1 CONSTRUCTOR
 
-The new() method can be used to create a Directory::Queue::Null object
-that will later be used to interact with the queue. No attributes are
-supported.
-
+The new() method can be used to create a Directory::Queue::Null object that
+will later be used to interact with the queue. No attributes are supported.
 
 =head1 METHODS
 
@@ -180,8 +178,7 @@ return the next element in the queue, so always an empty string
 
 =item add(DATA)
 
-add the given data (it can be anything) to the queue, this does
-nothing
+add the given data (it can be anything) to the queue, this does nothing
 
 =item add_ref(REF)
 
@@ -189,8 +186,8 @@ add the given data reference to the queue, this does nothing
 
 =item add_path(PATH)
 
-add the given file (identified by its path) to the queue, this will
-therefore B<remove> the file
+add the given file (identified by its path) to the queue, this will therefore
+B<remove> the file
 
 =item purge()
 
@@ -198,9 +195,9 @@ purge the queue, this does nothing
 
 =back
 
-The following methods are available to provide the same API as the
-other directory queue modules but they will always return an error as
-they cannot be legitimately called since the queue is always empty:
+The following methods are available to provide the same API as the other
+directory queue modules but they will always return an error as they cannot be
+legitimately called since the queue is always empty:
 
 =over
 
@@ -234,4 +231,4 @@ L<Directory::Queue::Simple>.
 
 Lionel Cons L<http://cern.ch/lionel.cons>
 
-Copyright (C) CERN 2010-2013
+Copyright (C) CERN 2010-2015
